@@ -19,6 +19,7 @@ import (
 	"strconv"
 	"strings"
 	"text/template"
+	"text/template/parse"
 	"time"
 
 	"ariga.io/atlas/cmd/atlas/internal/cmdext"
@@ -110,6 +111,7 @@ If run with the "--dry-run" flag, atlas will not execute any SQL.`,
 	addFlagURL(cmd.Flags(), &flags.url)
 	addFlagDirURL(cmd.Flags(), &flags.dirURL)
 	addFlagLog(cmd.Flags(), &flags.logFormat)
+	addFlagFormat(cmd.Flags(), &flags.logFormat)
 	addFlagRevisionSchema(cmd.Flags(), &flags.revisionSchema)
 	addFlagDryRun(cmd.Flags(), &flags.dryRun)
 	addFlagLockTimeout(cmd.Flags(), &flags.lockTimeout)
@@ -118,6 +120,7 @@ If run with the "--dry-run" flag, atlas will not execute any SQL.`,
 	cmd.Flags().StringVarP(&flags.txMode, flagTxMode, "", txModeFile, "set transaction mode [none, file, all]")
 	cmd.Flags().BoolVarP(&flags.allowDirty, flagAllowDirty, "", false, "allow start working on a non-clean database")
 	cmd.MarkFlagsMutuallyExclusive(flagFrom, flagBaseline)
+	cmd.MarkFlagsMutuallyExclusive(flagLog, flagFormat)
 	return cmd
 }
 
@@ -263,7 +266,7 @@ func reportApply(cmd *cobra.Command, flags migrateApplyFlags, r *cmdlog.MigrateA
 	if v := flags.logFormat; v != "" {
 		f, err = template.New("format").Funcs(cmdlog.ApplyTemplateFuncs).Parse(v)
 		if err != nil {
-			return fmt.Errorf("parse log format: %w", err)
+			return fmt.Errorf("parse format: %w", err)
 		}
 	}
 	if err = f.Execute(cmd.OutOrStdout(), r); err != nil {
@@ -282,6 +285,7 @@ type migrateDiffFlags struct {
 	devURL            string
 	schemas           []string
 	lockTimeout       time.Duration
+	format            string
 	revisionSchema    string // revision schema name
 	qualifier         string // optional table qualifier
 }
@@ -299,7 +303,7 @@ directory state to the desired schema. The desired state can be another connecte
 			Example: `  atlas migrate diff --dev-url mysql://user:pass@localhost:3306/dev --to file://schema.hcl
   atlas migrate diff --dev-url mysql://user:pass@localhost:3306/dev --to file://atlas.hcl add_users_table
   atlas migrate diff --dev-url mysql://user:pass@localhost:3306/dev --to mysql://user:pass@localhost:3306/dbname
-  atlas migrate diff --env dev`,
+  atlas migrate diff --env dev --format '{{ sql . "  " }}'`,
 			Args: cobra.MaximumNArgs(1),
 			PreRunE: func(cmd *cobra.Command, args []string) error {
 				if err := migrateFlagsFromEnv(cmd); err != nil {
@@ -323,6 +327,7 @@ directory state to the desired schema. The desired state can be another connecte
 	addFlagRevisionSchema(cmd.Flags(), &flags.revisionSchema)
 	addFlagSchemas(cmd.Flags(), &flags.schemas)
 	addFlagLockTimeout(cmd.Flags(), &flags.lockTimeout)
+	addFlagFormat(cmd.Flags(), &flags.format)
 	cmd.Flags().StringVar(&flags.qualifier, flagQualifier, "", "qualify tables with custom qualifier when working on a single schema")
 	cmd.Flags().BoolVarP(&flags.edit, flagEdit, "", false, "edit the generated migration file(s)")
 	cobra.CheckErr(cmd.MarkFlagRequired(flagTo))
@@ -358,22 +363,26 @@ func migrateDiffRun(cmd *cobra.Command, args []string, flags migrateDiffFlags) e
 	if flags.edit {
 		dir = &editDir{dir}
 	}
+	var name, indent string
+	if len(args) > 0 {
+		name = args[0]
+	}
 	f, err := formatter(u)
 	if err != nil {
 		return err
 	}
-	var name string
-	if len(args) > 0 {
-		name = args[0]
+	if f, indent, err = mayIndent(u, f, flags.format); err != nil {
+		return err
 	}
 	// If there is a state-loader that requires a custom
 	// 'migrate diff' handling, offload it the work.
 	if d, ok := cmdext.States.Differ(flags.desiredURLs); ok {
 		err := d.MigrateDiff(ctx, &cmdext.MigrateDiffOptions{
-			To:   flags.desiredURLs,
-			Name: name,
-			Dir:  dir,
-			Dev:  dev,
+			To:     flags.desiredURLs,
+			Name:   name,
+			Indent: indent,
+			Dir:    dir,
+			Dev:    dev,
 		})
 		return maskNoPlan(cmd, err)
 	}
@@ -389,7 +398,7 @@ func migrateDiffRun(cmd *cobra.Command, args []string, flags migrateDiffFlags) e
 		return err
 	}
 	defer desired.Close()
-	opts := []migrate.PlannerOption{migrate.PlanFormat(f)}
+	opts := []migrate.PlannerOption{migrate.PlanFormat(f), migrate.PlanWithIndent(indent)}
 	if dev.URL.Schema != "" {
 		// Disable tables qualifier in schema-mode.
 		opts = append(opts, migrate.PlanWithSchemaQualifier(flags.qualifier))
@@ -414,6 +423,54 @@ func migrateDiffRun(cmd *cobra.Command, args []string, flags migrateDiffFlags) e
 	}
 }
 
+func mayIndent(dir *url.URL, f migrate.Formatter, format string) (migrate.Formatter, string, error) {
+	if format == "" {
+		return f, "", nil
+	}
+	reject := errors.New(`'sql' can only be used to indent statements`)
+	t, err := template.New("format").
+		// The "sql" is a dummy function to detect if the
+		// template was used to indent the SQL statements.
+		Funcs(template.FuncMap{"sql": func(...any) (string, error) { return "", reject }}).
+		Parse(format)
+	if err != nil {
+		return nil, "", fmt.Errorf("parse format: %w", err)
+	}
+	indent, ok := func() (string, bool) {
+		if len(t.Tree.Root.Nodes) != 1 {
+			return "", false
+		}
+		n, ok := t.Tree.Root.Nodes[0].(*parse.ActionNode)
+		if !ok || len(n.Pipe.Cmds) != 1 || len(n.Pipe.Cmds[0].Args) < 2 || len(n.Pipe.Cmds[0].Args) > 3 {
+			return "", false
+		}
+		args := n.Pipe.Cmds[0].Args
+		if args[0].String() != "sql" || args[1].String() != "." && args[1].String() != "$" {
+			return "", false
+		}
+		d := `""` // empty string as arg.
+		if len(args) == 3 {
+			d = args[2].String()
+		}
+		return d, true
+	}()
+	if ok {
+		if indent, err = strconv.Unquote(indent); err != nil {
+			return nil, "", fmt.Errorf("parse indent: %w", err)
+		}
+		return f, indent, nil
+	}
+	// If the template is not an indent, it cannot contain the "sql" function.
+	if err := t.Execute(io.Discard, &migrate.Plan{}); err != nil && errors.Is(err, reject) {
+		return nil, "", fmt.Errorf("%v. got: %v", reject, t.Root.String())
+	}
+	tfs := f.(migrate.TemplateFormatter)
+	if len(tfs) != 1 {
+		return nil, "", fmt.Errorf("cannot use format with: %q", dir.Query().Get("format"))
+	}
+	return migrate.TemplateFormatter{{N: tfs[0].N, C: t}}, "", nil
+}
+
 // maskNoPlan masks ErrNoPlan errors.
 func maskNoPlan(cmd *cobra.Command, err error) error {
 	if errors.Is(err, migrate.ErrNoPlan) {
@@ -598,7 +655,7 @@ func migrateLintCmd() *cobra.Command {
 			Example: `  atlas migrate lint --env dev
   atlas migrate lint --dir file:///path/to/migration/directory --dev-url mysql://root:pass@localhost:3306 --latest 1
   atlas migrate lint --dir file:///path/to/migration/directory --dev-url mysql://root:pass@localhost:3306 --git-base master
-  atlas migrate lint --dir file:///path/to/migration/directory --dev-url mysql://root:pass@localhost:3306 --log '{{ json .Files }}'`,
+  atlas migrate lint --dir file:///path/to/migration/directory --dev-url mysql://root:pass@localhost:3306 --format '{{ json .Files }}'`,
 			PreRunE: func(cmd *cobra.Command, args []string) error {
 				if err := migrateFlagsFromEnv(cmd); err != nil {
 					return err
@@ -614,11 +671,13 @@ func migrateLintCmd() *cobra.Command {
 	addFlagDevURL(cmd.Flags(), &flags.devURL)
 	addFlagDirURL(cmd.Flags(), &flags.dirURL)
 	addFlagDirFormat(cmd.Flags(), &flags.dirFormat)
-	cmd.Flags().StringVarP(&flags.logFormat, flagLog, "", "", "custom logging using a Go template")
+	addFlagLog(cmd.Flags(), &flags.logFormat)
+	addFlagFormat(cmd.Flags(), &flags.logFormat)
 	cmd.Flags().UintVarP(&flags.latest, flagLatest, "", 0, "run analysis on the latest N migration files")
 	cmd.Flags().StringVarP(&flags.gitBase, flagGitBase, "", "", "run analysis against the base Git branch")
 	cmd.Flags().StringVarP(&flags.gitDir, flagGitDir, "", ".", "path to the repository working directory")
 	cobra.CheckErr(cmd.MarkFlagRequired(flagDevURL))
+	cmd.MarkFlagsMutuallyExclusive(flagLog, flagFormat)
 	return cmd
 }
 
@@ -655,7 +714,7 @@ func migrateLintRun(cmd *cobra.Command, _ []string, flags migrateLintFlags) erro
 	if f := flags.logFormat; f != "" {
 		format, err = template.New("format").Funcs(lint.TemplateFuncs).Parse(f)
 		if err != nil {
-			return fmt.Errorf("parse log format: %w", err)
+			return fmt.Errorf("parse format: %w", err)
 		}
 	}
 	env, err := selectEnv(GlobalFlags.SelectedEnv)
@@ -973,9 +1032,11 @@ func migrateStatusCmd() *cobra.Command {
 	cmd.Flags().SortFlags = false
 	addFlagURL(cmd.Flags(), &flags.url)
 	addFlagLog(cmd.Flags(), &flags.logFormat)
+	addFlagFormat(cmd.Flags(), &flags.logFormat)
 	addFlagDirURL(cmd.Flags(), &flags.dirURL)
 	addFlagDirFormat(cmd.Flags(), &flags.dirFormat)
 	addFlagRevisionSchema(cmd.Flags(), &flags.revisionSchema)
+	cmd.MarkFlagsMutuallyExclusive(flagLog, flagFormat)
 	return cmd
 }
 
@@ -1003,7 +1064,7 @@ func migrateStatusRun(cmd *cobra.Command, _ []string, flags migrateStatusFlags)
 	format := cmdlog.MigrateStatusTemplate
 	if f := flags.logFormat; f != "" {
 		if format, err = template.New("format").Funcs(cmdlog.StatusTemplateFuncs).Parse(f); err != nil {
-			return fmt.Errorf("parse log format: %w", err)
+			return fmt.Errorf("parse format: %w", err)
 		}
 	}
 	return format.Execute(cmd.OutOrStdout(), report)
@@ -1265,7 +1326,7 @@ func (tx *tx) modeFor(f migrate.File) (string, error) {
 }
 
 func operatorVersion() string {
-	v, _ := parse(version)
+	v, _ := parseV(version)
 	return "Atlas CLI " + v
 }
 
@@ -1505,7 +1566,7 @@ func setMigrateEnvFlags(cmd *cobra.Command, env *Env) error {
 	}
 	switch cmd.Name() {
 	case "apply":
-		if err := maySetFlag(cmd, flagLog, env.Log.Migrate.Apply); err != nil {
+		if err := maySetFlag(cmd, flagFormat, env.Format.Migrate.Apply); err != nil {
 			return err
 		}
 		if err := maySetFlag(cmd, flagLockTimeout, env.Migration.LockTimeout); err != nil {
@@ -1515,11 +1576,14 @@ func setMigrateEnvFlags(cmd *cobra.Command, env *Env) error {
 		if err := maySetFlag(cmd, flagLockTimeout, env.Migration.LockTimeout); err != nil {
 			return err
 		}
-	case "lint":
-		if err := maySetFlag(cmd, flagLog, env.Log.Migrate.Lint); err != nil {
+		if err := maySetFlag(cmd, flagFormat, env.Format.Migrate.Diff); err != nil {
 			return err
 		}
-		if err := maySetFlag(cmd, flagLog, env.Lint.Log); err != nil {
+	case "lint":
+		if err := maySetFlag(cmd, flagFormat, env.Format.Migrate.Lint); err != nil {
+			return err
+		}
+		if err := maySetFlag(cmd, flagFormat, env.Lint.Format); err != nil {
 			return err
 		}
 		if err := maySetFlag(cmd, flagLatest, strconv.Itoa(env.Lint.Latest)); err != nil {
@@ -1532,7 +1596,7 @@ func setMigrateEnvFlags(cmd *cobra.Command, env *Env) error {
 			return err
 		}
 	case "status":
-		if err := maySetFlag(cmd, flagLog, env.Log.Migrate.Status); err != nil {
+		if err := maySetFlag(cmd, flagFormat, env.Format.Migrate.Status); err != nil {
 			return err
 		}
 	}
@@ -1583,7 +1647,7 @@ func cmdEnvsRun[F any](
 		b := bytes.TrimLeft(w.Bytes(), " \t\r")
 		// In case a custom logging was configured, ensure there is
 		// a newline separator between the different environments.
-		if cmd.Flags().Changed(flagLog) && bytes.LastIndexByte(b, '\n') != len(b)-1 && i != len(envs)-1 {
+		if cmd.Flags().Changed(flagFormat) && bytes.LastIndexByte(b, '\n') != len(b)-1 && i != len(envs)-1 {
 			cmd.Println()
 		}
 		reset()
