@@ -58,7 +58,6 @@ type schemaApplyFlags struct {
 	dryRun      bool     // Only show SQL on screen instead of applying it.
 	autoApprove bool     // Don't prompt for approval before applying SQL.
 	logFormat   string   // Log format.
-	dsn         string   // Deprecated: DSN is an alias for URL.
 }
 
 // schemaApplyCmd represents the 'atlas schema apply' subcommand.
@@ -89,9 +88,6 @@ migration.`,
   atlas schema apply -u "mariadb://user:pass@localhost:3306/dbname" --to file://schema.hcl
   atlas schema apply --url "postgres://user:pass@host:port/dbname?sslmode=disable" --to file://schema.hcl
   atlas schema apply -u "sqlite://file:ex1.db?_fk=1" --to file://schema.hcl`,
-			PreRunE: func(cmd *cobra.Command, _ []string) error {
-				return dsn2url(cmd)
-			},
 			RunE: func(cmd *cobra.Command, args []string) error {
 				if GlobalFlags.SelectedEnv == "" {
 					return schemaApplyRun(cmd, args, flags)
@@ -108,12 +104,13 @@ migration.`,
 	addFlagDevURL(cmd.Flags(), &flags.devURL)
 	addFlagDryRun(cmd.Flags(), &flags.dryRun)
 	addFlagAutoApprove(cmd.Flags(), &flags.autoApprove)
-	cmd.Flags().StringVarP(&flags.logFormat, flagLog, "", "", "custom logging using a Go template")
-	addFlagDSN(cmd.Flags(), &flags.dsn)
+	addFlagLog(cmd.Flags(), &flags.logFormat)
+	addFlagFormat(cmd.Flags(), &flags.logFormat)
 	// Hidden support for the deprecated -f flag.
 	cmd.Flags().StringSliceVarP(&flags.paths, flagFile, "f", nil, "[paths...] file or directory containing HCL or SQL files")
 	cobra.CheckErr(cmd.Flags().MarkHidden(flagFile))
 	cmd.MarkFlagsMutuallyExclusive(flagFile, flagTo)
+	cmd.MarkFlagsMutuallyExclusive(flagLog, flagFormat)
 	return cmd
 }
 
@@ -124,7 +121,7 @@ func schemaApplyRun(cmd *cobra.Command, _ []string, flags schemaApplyFlags) erro
 	case len(flags.paths) == 0 && len(flags.toURLs) == 0:
 		return errors.New(`one of flag(s) "file" or "to" is required`)
 	case flags.logFormat != "" && !flags.dryRun && !flags.autoApprove:
-		return errors.New(`--log can only be used with --dry-run or --auto-approve`)
+		return errors.New(`--log and --format can only be used with --dry-run or --auto-approve`)
 	}
 	// If the old -f flag is given convert them to the URL format. If both are given,
 	// cobra would throw an error since they are marked as mutually exclusive.
@@ -185,14 +182,15 @@ func schemaApplyRun(cmd *cobra.Command, _ []string, flags schemaApplyFlags) erro
 	cmd.SilenceUsage = true
 	switch {
 	case len(changes) == 0:
-		return format.Execute(cmd.OutOrStderr(), &cmdlog.SchemaApply{})
+		return format.Execute(cmd.OutOrStdout(), &cmdlog.SchemaApply{})
 	case flags.logFormat != "" && flags.autoApprove:
 		var (
 			applied int
 			plan    *migrate.Plan
 			cause   *cmdlog.StmtError
+			out     = cmd.OutOrStdout()
 		)
-		if plan, err = client.PlanChanges(cmd.Context(), "", changes); err != nil {
+		if plan, err = client.PlanChanges(ctx, "", changes); err != nil {
 			return err
 		}
 		if err = client.ApplyChanges(ctx, changes); err == nil {
@@ -203,7 +201,7 @@ func schemaApplyRun(cmd *cobra.Command, _ []string, flags schemaApplyFlags) erro
 			cause = &cmdlog.StmtError{Text: err.Error()}
 		}
 		apply := cmdlog.NewSchemaApply(cmdlog.NewEnv(client, nil), plan.Changes[:applied], plan.Changes[applied:], cause)
-		if err1 := format.Execute(cmd.OutOrStderr(), apply); err1 != nil {
+		if err1 := format.Execute(out, apply); err1 != nil {
 			if err != nil {
 				err1 = fmt.Errorf("%w: %v", err, err1)
 			}
@@ -238,10 +236,7 @@ As a safety feature, 'atlas schema clean' will ask for confirmation before attem
 			Example: `  atlas schema clean -u mysql://user:pass@localhost:3306/dbname
   atlas schema clean -u mysql://user:pass@localhost:3306/`,
 			PreRunE: func(cmd *cobra.Command, _ []string) error {
-				if err := schemaFlagsFromEnv(cmd); err != nil {
-					return err
-				}
-				return dsn2url(cmd)
+				return schemaFlagsFromEnv(cmd)
 			},
 			RunE: func(cmd *cobra.Command, args []string) error {
 				return schemaCleanRun(cmd, args, flags)
@@ -305,6 +300,7 @@ type schemaDiffFlags struct {
 	devURL  string
 	schemas []string
 	exclude []string
+	format  string
 }
 
 // schemaDiffCmd represents the 'atlas schema diff' subcommand.
@@ -320,12 +316,9 @@ SQL statements to migrate the "from" database to the schema of the "to" database
 The database states can be read from a connected database, an HCL project or a migration directory.`,
 			Example: `  atlas schema diff --from mysql://user:pass@localhost:3306/test --to file://schema.hcl
   atlas schema diff --from mysql://user:pass@localhost:3306 --to file://schema_1.hcl --to file://schema_2.hcl
-  atlas schema diff --from mysql://user:pass@localhost:3306 --to file://migrations`,
+  atlas schema diff --from mysql://user:pass@localhost:3306 --to file://migrations --format '{{ sql . "  " }}'`,
 			PreRunE: func(cmd *cobra.Command, _ []string) error {
-				if err := schemaFlagsFromEnv(cmd); err != nil {
-					return err
-				}
-				return dsn2url(cmd)
+				return schemaFlagsFromEnv(cmd)
 			},
 			RunE: func(cmd *cobra.Command, args []string) error {
 				return schemaDiffRun(cmd, args, flags)
@@ -338,6 +331,7 @@ The database states can be read from a connected database, an HCL project or a m
 	addFlagDevURL(cmd.Flags(), &flags.devURL)
 	addFlagSchemas(cmd.Flags(), &flags.schemas)
 	addFlagExclude(cmd.Flags(), &flags.exclude)
+	addFlagFormat(cmd.Flags(), &flags.format)
 	cobra.CheckErr(cmd.MarkFlagRequired(flagFrom))
 	cobra.CheckErr(cmd.MarkFlagRequired(flagTo))
 	return cmd
@@ -384,11 +378,20 @@ func schemaDiffRun(cmd *cobra.Command, _ []string, flags schemaDiffFlags) error
 		// an error already. If we land in this case, we can assume both states are database connections.
 		c = to.Closer.(*sqlclient.Client)
 	}
-	diff, err := computeDiff(ctx, c, from, to)
+	format := cmdlog.SchemaDiffTemplate
+	if v := flags.format; v != "" {
+		if format, err = template.New("format").Funcs(cmdlog.SchemaDiffFuncs).Parse(v); err != nil {
+			return fmt.Errorf("parse log format: %w", err)
+		}
+	}
+	changes, err := computeDiff(ctx, c, from, to)
 	if err != nil {
 		return err
 	}
-	return summary(cmd, c, diff, cmdlog.SchemaDiffTemplate)
+	return format.Execute(cmd.OutOrStdout(), &cmdlog.SchemaDiff{
+		Client:  c,
+		Changes: changes,
+	})
 }
 
 type schemaInspectFlags struct {
@@ -396,7 +399,6 @@ type schemaInspectFlags struct {
 	logFormat string   // Format of the log output.
 	schemas   []string // Schemas to take into account when diffing.
 	exclude   []string // List of glob patterns used to filter resources from applying (see schema.InspectOptions).
-	dsn       string   // Deprecated: DSN is an alias for URL.
 }
 
 // schemaInspectCmd represents the 'atlas schema inspect' subcommand.
@@ -424,10 +426,7 @@ flag.
   atlas schema inspect --url "postgres://user:pass@host:port/dbname?sslmode=disable"
   atlas schema inspect -u "sqlite://file:ex1.db?_fk=1"`,
 			PreRunE: func(cmd *cobra.Command, _ []string) error {
-				if err := schemaFlagsFromEnv(cmd); err != nil {
-					return err
-				}
-				return dsn2url(cmd)
+				return schemaFlagsFromEnv(cmd)
 			},
 			RunE: func(cmd *cobra.Command, args []string) error {
 				return schemaInspectRun(cmd, args, flags)
@@ -439,8 +438,9 @@ flag.
 	addFlagSchemas(cmd.Flags(), &flags.schemas)
 	addFlagExclude(cmd.Flags(), &flags.exclude)
 	addFlagLog(cmd.Flags(), &flags.logFormat)
-	addFlagDSN(cmd.Flags(), &flags.dsn)
+	addFlagFormat(cmd.Flags(), &flags.logFormat)
 	cobra.CheckErr(cmd.MarkFlagRequired(flagURL))
+	cmd.MarkFlagsMutuallyExclusive(flagLog, flagFormat)
 	return cmd
 }
 
@@ -566,7 +566,11 @@ func setSchemaEnvFlags(cmd *cobra.Command, env *Env) error {
 	}
 	switch cmd.Name() {
 	case "apply":
-		if err := maySetFlag(cmd, flagLog, env.Log.Schema.Apply); err != nil {
+		if err := maySetFlag(cmd, flagFormat, env.Format.Schema.Apply); err != nil {
+			return err
+		}
+	case "diff":
+		if err := maySetFlag(cmd, flagFormat, env.Format.Schema.Diff); err != nil {
 			return err
 		}
 	}
