@@ -46,6 +46,16 @@ func TestSchema_Diff(t *testing.T) {
 	require.NoError(t, err)
 	require.EqualValues(t, "-- Create \"t1\" table\nCREATE TABLE `t1` (`id` int NULL);\n", s)
 
+	// Format indentation one table.
+	s, err = runCmd(
+		schemaDiffCmd(),
+		"--from", openSQLite(t, ""),
+		"--to", openSQLite(t, "create table t1 (id int);"),
+		"--format", `{{ sql . "  " }}`,
+	)
+	require.NoError(t, err)
+	require.EqualValues(t, "-- Create \"t1\" table\nCREATE TABLE `t1` (\n  `id` int NULL\n);\n", s)
+
 	// No changes.
 	s, err = runCmd(
 		schemaDiffCmd(),
@@ -55,6 +65,16 @@ func TestSchema_Diff(t *testing.T) {
 	require.NoError(t, err)
 	require.EqualValues(t, "Schemas are synced, no changes to be made.\n", s)
 
+	// Format no changes.
+	s, err = runCmd(
+		schemaDiffCmd(),
+		"--from", openSQLite(t, ""),
+		"--to", openSQLite(t, ""),
+		"--format", `{{ sql . " " }}`,
+	)
+	require.NoError(t, err)
+	require.Empty(t, s)
+
 	// Desired state from migration directory requires dev database.
 	_, err = runCmd(
 		schemaDiffCmd(),
@@ -202,7 +222,15 @@ table "tbl" {
 			p   = t.TempDir()
 			cp  = filepath.Join(p, "atlas.hcl")
 			sp  = filepath.Join(p, "schema.hcl")
-			cfg = fmt.Sprintf(`env "local" { dev = "%s" }`, openSQLite(t, ""))
+			cfg = fmt.Sprintf(`
+env "local" {
+  dev = "%s"
+  format {
+    schema {
+      diff = "{{ sql . \"\t\" }}"
+    }
+  }
+}`, openSQLite(t, ""))
 		)
 		require.NoError(t, os.WriteFile(cp, []byte(cfg), 0600))
 		require.NoError(t, os.WriteFile(sp, []byte(`
@@ -225,7 +253,7 @@ table "users" {
 			"--from", openSQLite(t, ""),
 		)
 		require.NoError(t, err)
-		require.Equal(t, "-- Create \"users\" table\nCREATE TABLE `users` (`id` int NOT NULL);\n", s)
+		require.Equal(t, "-- Create \"users\" table\nCREATE TABLE `users` (\n\t`id` int NOT NULL\n);\n", s)
 	})
 }
 
@@ -328,7 +356,7 @@ func TestSchema_ApplyLog(t *testing.T) {
 			"-u", db,
 			"--to", openSQLite(t, ""),
 			"--dry-run",
-			"--log", "{{ json .Changes }}",
+			"--format", "{{ json .Changes }}",
 		)
 		require.NoError(t, err)
 		require.Equal(t, "{}", s)
@@ -340,7 +368,7 @@ func TestSchema_ApplyLog(t *testing.T) {
 			"-u", db,
 			"--to", openSQLite(t, "create table t1 (id int);"),
 			"--dry-run",
-			"--log", "{{ json .Changes }}",
+			"--format", "{{ json .Changes }}",
 		)
 		require.NoError(t, err)
 		require.Equal(t, "{\"Pending\":[\"CREATE TABLE `t1` (`id` int NULL)\"]}", s)
@@ -355,7 +383,7 @@ func TestSchema_ApplyLog(t *testing.T) {
 			"-u", db,
 			"--to", openSQLite(t, "create table t1 (id int);"),
 			"--auto-approve",
-			"--log", "{{ json .Changes }}",
+			"--format", "{{ json .Changes }}",
 		)
 		require.NoError(t, err)
 		require.Equal(t, "{\"Applied\":[\"CREATE TABLE `t1` (`id` int NULL)\"]}", s)
@@ -367,7 +395,7 @@ func TestSchema_ApplyLog(t *testing.T) {
 			"-u", db,
 			"--to", openSQLite(t, "create table t1 (id int);"),
 			"--auto-approve",
-			"--log", "{{ json .Changes }}",
+			"--format", "{{ json .Changes }}",
 		)
 		require.NoError(t, err)
 		require.Equal(t, "{}", s)
@@ -379,7 +407,7 @@ func TestSchema_ApplyLog(t *testing.T) {
 			"-u", db,
 			"--to", openSQLite(t, "create table t2 (id int);"),
 			"--auto-approve",
-			"--log", "{{ json .Changes }}",
+			"--format", "{{ json .Changes }}",
 		)
 		require.NoError(t, err)
 		require.Equal(t, "{\"Applied\":[\"PRAGMA foreign_keys = off\",\"DROP TABLE `t1`\",\"CREATE TABLE `t2` (`id` int NULL)\",\"PRAGMA foreign_keys = on\"]}", s)
@@ -397,7 +425,7 @@ func TestSchema_ApplyLog(t *testing.T) {
 			"-u", db,
 			"--to", openSQLite(t, "create table t2 (id int, c int);create unique index t2_id on t2 (id);"),
 			"--auto-approve",
-			"--log", "{{ json .Changes }}\n",
+			"--format", "{{ json .Changes }}\n",
 		)
 		require.EqualError(t, err, `create index "t2_id" to table: "t2": UNIQUE constraint failed: t2.id`)
 		var out struct {
@@ -553,7 +581,7 @@ func TestSchema_InspectLog(t *testing.T) {
 	s, err := runCmd(
 		cmd, "inspect",
 		"-u", db,
-		"--log", "{{ json . }}",
+		"--format", "{{ json . }}",
 	)
 	require.NoError(t, err)
 	require.Equal(t, `{"schemas":[{"name":"main","tables":[{"name":"t1","columns":[{"name":"id","type":"INTEGER","null":true}],"primary_key":{"parts":[{"column":"id"}]}},{"name":"t2","columns":[{"name":"name","type":"TEXT","null":true}]}]}]}`, s)
