@@ -15,6 +15,7 @@ import (
 	"net/url"
 	"os"
 	"os/exec"
+	"path"
 	"strconv"
 	"strings"
 	"time"
@@ -84,12 +85,12 @@ func FromURL(u *url.URL) (*Config, error) {
 	switch u.Host {
 	case "mysql":
 		if len(parts) > 1 {
-			opts = append(opts, Env("MYSQL_DATABASE="+parts[1]))
+			opts = append(opts, Env("MYSQL_DATABASE="+parts[1]), setup(fmt.Sprintf("CREATE DATABASE IF NOT EXISTS `%s`", parts[1])))
 		}
 		return MySQL(tag, opts...)
 	case "maria", "mariadb":
 		if len(parts) > 1 {
-			opts = append(opts, Env("MYSQL_DATABASE="+parts[1]))
+			opts = append(opts, Env("MYSQL_DATABASE="+parts[1]), setup(fmt.Sprintf("CREATE DATABASE IF NOT EXISTS `%s`", parts[1])))
 		}
 		return MariaDB(tag, opts...)
 	case "postgres":
@@ -102,12 +103,16 @@ func FromURL(u *url.URL) (*Config, error) {
 	}
 }
 
+// Atlas DockerHub user contains the MySQL
+// and MariaDB images with faster boot times.
+const hubUser = "arigaio"
+
 // MySQL returns a new Config for a MySQL image.
 func MySQL(version string, opts ...ConfigOption) (*Config, error) {
 	return NewConfig(
 		append(
 			[]ConfigOption{
-				Image("mysql:" + version),
+				Image(hubUser, "mysql:"+version),
 				Port("3306"),
 				Env("MYSQL_ROOT_PASSWORD=" + pass),
 			},
@@ -118,7 +123,7 @@ func MySQL(version string, opts ...ConfigOption) (*Config, error) {
 
 // MariaDB returns a new Config for a MariaDB image.
 func MariaDB(version string, opts ...ConfigOption) (*Config, error) {
-	return MySQL(version, append([]ConfigOption{Image("mariadb:" + version)}, opts...)...)
+	return MySQL(version, append([]ConfigOption{Image(hubUser, "mariadb:"+version)}, opts...)...)
 }
 
 // PostgreSQL returns a new Config for a PostgreSQL image.
@@ -139,10 +144,14 @@ func PostgreSQL(version string, opts ...ConfigOption) (*Config, error) {
 // Image sets the docker image to use. For example:
 //
 //	Image("mysql")
+//	Image("arigaio", "mysql")
 //	Image("postgres:13")
-func Image(i string) ConfigOption {
+func Image(parts ...string) ConfigOption {
 	return func(c *Config) error {
-		c.Image = strings.TrimSuffix(i, ":")
+		if len(parts) == 0 || len(parts) > 2 {
+			return errors.New("image path must be in the format of 'image' or 'user/image'")
+		}
+		c.Image = strings.TrimSuffix(path.Join(parts...), ":")
 		return nil
 	}
 }
@@ -188,6 +197,17 @@ func Out(w io.Writer) ConfigOption {
 	}
 }
 
+// setup adds statements to execute once the service is ready. For example:
+//
+//	setup("CREATE DATABASE IF NOT EXISTS test")
+//	setup("DROP SCHEMA IF EXISTS public CASCADE")
+func setup(s ...string) ConfigOption {
+	return func(c *Config) error {
+		c.setup = s
+		return nil
+	}
+}
+
 // Run pulls and starts a new docker container from the Config.
 func (c *Config) Run(ctx context.Context) (*Container, error) {
 	// Make sure the configuration is not missing critical values.
@@ -200,10 +220,9 @@ func (c *Config) Run(ctx context.Context) (*Container, error) {
 		return nil, fmt.Errorf("getting open port: %w", err)
 	}
 	// Make sure the image is up-to-date.
-	cmd := exec.CommandContext(ctx, "docker", "pull", c.Image) //nolint:gosec
-	cmd.Stdout = c.Out
-	if err := cmd.Run(); err != nil {
-		return nil, fmt.Errorf("pulling image: %w", err)
+	out, err := exec.CommandContext(ctx, "docker", "pull", c.Image).CombinedOutput() //nolint:gosec
+	if err != nil {
+		return nil, fmt.Errorf("pulling image: %w: %q", err, out)
 	}
 	// Run the container.
 	args := []string{"docker", "run", "--rm", "--detach"}
@@ -211,15 +230,15 @@ func (c *Config) Run(ctx context.Context) (*Container, error) {
 		args = append(args, "-e", e)
 	}
 	args = append(args, "-p", fmt.Sprintf("%s:%s", p, c.Port), c.Image)
-	cmd = exec.CommandContext(ctx, args[0], args[1:]...) //nolint:gosec
-	out := &bytes.Buffer{}
-	cmd.Stdout = io.MultiWriter(c.Out, out)
+	cmd := exec.CommandContext(ctx, args[0], args[1:]...) //nolint:gosec
+	buf := &bytes.Buffer{}
+	cmd.Stdout = io.MultiWriter(c.Out, buf)
 	if err := cmd.Run(); err != nil {
 		return nil, err
 	}
 	return &Container{
 		cfg:        *c,
-		ID:         strings.TrimSpace(out.String()),
+		ID:         strings.TrimSpace(buf.String()),
 		Passphrase: pass,
 		Port:       p,
 		out:        c.Out,
@@ -228,7 +247,7 @@ func (c *Config) Run(ctx context.Context) (*Container, error) {
 
 // Close stops and removes this container.
 func (c *Container) Close() error {
-	return exec.Command("docker", "stop", c.ID).Run() //nolint:gosec
+	return exec.Command("docker", "kill", c.ID).Run() //nolint:gosec
 }
 
 // Wait waits for this container to be ready.
@@ -249,7 +268,9 @@ func (c *Container) Wait(ctx context.Context, timeout time.Duration) error {
 	for {
 		select {
 		case <-time.After(100 * time.Millisecond):
-			client, err := sqlclient.Open(ctx, u)
+			// Ping against the root connection.
+			u.Path = "/"
+			client, err := sqlclient.Open(ctx, u.String())
 			if err != nil {
 				continue
 			}
@@ -275,14 +296,14 @@ func (c *Container) Wait(ctx context.Context, timeout time.Duration) error {
 }
 
 // URL returns a URL to connect to the Container.
-func (c *Container) URL() (string, error) {
-	switch img := strings.SplitN(c.cfg.Image, ":", 2)[0]; img {
+func (c *Container) URL() (*url.URL, error) {
+	switch img := path.Base(strings.SplitN(c.cfg.Image, ":", 2)[0]); img {
 	case "postgres":
-		return fmt.Sprintf("postgres://postgres:%s@localhost:%s/%s?sslmode=disable", c.Passphrase, c.Port, c.cfg.Database), nil
+		return url.Parse(fmt.Sprintf("postgres://postgres:%s@localhost:%s/%s?sslmode=disable", c.Passphrase, c.Port, c.cfg.Database))
 	case "mysql", "mariadb":
-		return fmt.Sprintf("%s://root:%s@localhost:%s/%s", img, c.Passphrase, c.Port, c.cfg.Database), nil
+		return url.Parse(fmt.Sprintf("%s://root:%s@localhost:%s/%s", img, c.Passphrase, c.Port, c.cfg.Database))
 	default:
-		return "", fmt.Errorf("unknown container image: %q", img)
+		return nil, fmt.Errorf("unknown container image: %q", img)
 	}
 }
 
@@ -318,10 +339,13 @@ func client(ctx context.Context, u *url.URL) (client *sqlclient.Client, err erro
 	if err != nil {
 		return nil, err
 	}
-	if u.Query().Has("v") || u.Query().Has("verbose") {
+	qr := u.Query()
+	if qr.Has("v") || qr.Has("verbose") {
 		if err := Out(os.Stdout)(cfg); err != nil {
 			return nil, err
 		}
+		qr.Del("v")
+		qr.Del("verbose")
 	}
 	c, err := cfg.Run(ctx)
 	if err != nil {
@@ -341,7 +365,11 @@ func client(ctx context.Context, u *url.URL) (client *sqlclient.Client, err erro
 	if err != nil {
 		return nil, err
 	}
-	if client, err = sqlclient.Open(ctx, u1); err != nil {
+	for k, v := range u1.Query() {
+		qr[k] = v
+	}
+	u1.RawQuery = qr.Encode()
+	if client, err = sqlclient.Open(ctx, u1.String()); err != nil {
 		return nil, err
 	}
 	client.AddClosers(c)
