@@ -180,7 +180,7 @@ func TestDevLoader_LoadChanges(t *testing.T) {
 	})
 	require.NoError(t, err)
 	_, err = l.LoadChanges(ctx, base, files)
-	require.ErrorAs(t, err, &migrate.NotCleanError{})
+	require.ErrorAs(t, err, new(*migrate.NotCleanError))
 }
 
 type testDir struct {
@@ -216,3 +216,14 @@ func (f testFile) Bytes() []byte {
 func (f testFile) Stmts() ([]string, error) {
 	return strings.Split(string(f.Bytes()), "\n"), nil
 }
+
+func (f testFile) StmtDecls() (stmts []*migrate.Stmt, err error) {
+	s, err := f.Stmts()
+	if err != nil {
+		return nil, err
+	}
+	for _, s := range s {
+		stmts = append(stmts, &migrate.Stmt{Text: s})
+	}
+	return
+}
