@@ -53,7 +53,12 @@ module.exports = {
           href: 'https://twitter.com/ariga_io',
           className: 'header-twitter-link',
           position: 'right',
+        },{
+          href: 'https://atlasnewsletter.substack.com/',
+          className: 'header-newsletter-link',
+          position: 'right',
         },
+        
         {
           to: 'getting-started',
           label: 'Docs',
@@ -91,7 +96,9 @@ module.exports = {
           "items": [
             {"label": "GitHub", "to": "https://github.com/ariga/atlas"},
             {"label": "Discord", "to": "https://discord.gg/zZ6sWVg6NT"},
-            {"label": "Twitter", "to": "https://twitter.com/ariga_io"}
+            {"label": "Twitter", "to": "https://twitter.com/ariga_io"},
+            {"label": "Newsletter", "to": "https://atlasnewsletter.substack.com/"},
+            {"label": "YouTube", "to": "https://youtube.com/@ariga_io"}
           ]
         },
         {
@@ -120,8 +127,8 @@ module.exports = {
       `,
     },
     announcementBar: {
-      id: 'announcementBar-1', // Increment on change
-      content: `️🚀 Sign up for a user testing session and receive exclusive Atlas swag, register <a target="_blank" rel="noopener noreferrer" href="https://calendly.com/ariga-user-testing/atlas-user-testing">here!</a>`,
+      id: 'announcementBar-2', // Increment on change
+      content: `️🚀 Read the latest updates in <a target="_blank" rel="noopener noreferrer" href="https://atlasnewsletter.substack.com/archive">our newsletter!</a>`, 
       isCloseable: true,
     },
   },
@@ -194,6 +201,10 @@ module.exports = {
             to: '/guides/ddl',
             from: '/knowledge/ddl',
           },
+          {
+            to: '/concepts/url',
+            from: '/url',
+          },
         ],
       },
     ],
