@@ -328,6 +328,7 @@ func TestPlanChanges(t *testing.T) {
 		{
 			changes: []schema.Change{
 				&schema.DropTable{T: schema.NewTable("posts").AddColumns(schema.NewIntColumn("id", "int"))},
+				&schema.DropTable{T: schema.NewTable("users").AddColumns(schema.NewIntColumn("id", "int")), Extra: []schema.Clause{&Cascade{}}},
 			},
 			wantPlan: &migrate.Plan{
 				Reversible:    true,
@@ -337,6 +338,10 @@ func TestPlanChanges(t *testing.T) {
 						Cmd:     `DROP TABLE "posts"`,
 						Reverse: `CREATE TABLE "posts" ("id" integer NOT NULL)`,
 					},
+					{
+						Cmd:     `DROP TABLE "users" CASCADE`,
+						Reverse: `CREATE TABLE "users" ("id" integer NOT NULL)`,
+					},
 				},
 			},
 		},
@@ -791,6 +796,81 @@ func TestPlanChanges(t *testing.T) {
 				},
 			},
 		},
+		{
+			changes: []schema.Change{
+				&schema.DropTable{
+					T: schema.NewTable("users").
+						SetSchema(schema.New("public")).
+						AddColumns(
+							schema.NewEnumColumn("state", schema.EnumName("state"), schema.EnumValues("on", "off")),
+							schema.NewEnumColumn("status", schema.EnumName("status"), schema.EnumValues("on", "off")),
+						),
+				},
+			},
+			mock: func(m mock) {
+				m.ExpectQuery(sqltest.Escape("SELECT * FROM pg_type t JOIN pg_namespace n on t.typnamespace = n.oid WHERE t.typname = $1 AND t.typtype = 'e' AND n.nspname = $2 ")).
+					WithArgs("state", "public").
+					WillReturnRows(sqlmock.NewRows([]string{"name"}))
+				m.ExpectQuery(sqltest.Escape("SELECT * FROM pg_type t JOIN pg_namespace n on t.typnamespace = n.oid WHERE t.typname = $1 AND t.typtype = 'e' AND n.nspname = $2 ")).
+					WithArgs("status", "public").
+					WillReturnRows(sqlmock.NewRows([]string{"name"}))
+			},
+			wantPlan: &migrate.Plan{
+				Reversible:    true,
+				Transactional: true,
+				Changes: []*migrate.Change{
+					{Cmd: `DROP TABLE "public"."users"`, Reverse: `CREATE TABLE "public"."users" ("state" "public"."state" NOT NULL, "status" "public"."status" NOT NULL)`},
+					{Cmd: `DROP TYPE "public"."state"`, Reverse: `CREATE TYPE "public"."state" AS ENUM ('on', 'off')`},
+					{Cmd: `DROP TYPE "public"."status"`, Reverse: `CREATE TYPE "public"."status" AS ENUM ('on', 'off')`},
+				},
+			},
+		},
+		{
+			changes: func() []schema.Change {
+				s := schema.New("public").
+					AddTables(
+						schema.NewTable("t1").
+							AddColumns(
+								schema.NewEnumColumn("state", schema.EnumName("state"), schema.EnumValues("on", "off")),
+							),
+						schema.NewTable("t2").
+							AddColumns(
+								schema.NewEnumColumn("state", schema.EnumName("state"), schema.EnumValues("on", "off")),
+							),
+					)
+				return []schema.Change{
+					&schema.DropTable{
+						T: s.Tables[0],
+					},
+					&schema.DropTable{
+						T: s.Tables[1],
+					},
+				}
+			}(),
+			mock: func(m mock) {
+				m.ExpectQuery(sqltest.Escape("SELECT * FROM pg_type t JOIN pg_namespace n on t.typnamespace = n.oid WHERE t.typname = $1 AND t.typtype = 'e' AND n.nspname = $2 ")).
+					WithArgs("state", "public").
+					WillReturnRows(sqlmock.NewRows([]string{"name"}).AddRow("state"))
+				m.ExpectQuery(sqltest.Escape("SELECT * FROM pg_type t JOIN pg_namespace n on t.typnamespace = n.oid WHERE t.typname = $1 AND t.typtype = 'e' AND n.nspname = $2 ")).
+					WithArgs("state", "public").
+					WillReturnRows(sqlmock.NewRows([]string{"name"}).AddRow("state"))
+			},
+			wantPlan: &migrate.Plan{
+				Reversible:    true,
+				Transactional: true,
+				Changes: []*migrate.Change{
+					{
+						Cmd:     `DROP TABLE "public"."t1"`,
+						Reverse: `CREATE TABLE "public"."t1" ("state" "public"."state" NOT NULL)`,
+					},
+					{
+						Cmd:     `DROP TABLE "public"."t2"`,
+						Reverse: `CREATE TABLE "public"."t2" ("state" "public"."state" NOT NULL)`,
+					},
+					{Cmd: `DROP TYPE "public"."state"`, Reverse: `CREATE TYPE "public"."state" AS ENUM ('on', 'off')`},
+				},
+			},
+		},
 		{
 			changes: []schema.Change{
 				func() schema.Change {
@@ -1370,3 +1450,117 @@ func TestDefaultPlan(t *testing.T) {
 	})
 	require.EqualError(t, err, `create "t1" table: cannot execute statements without a database connection. use Open to create a new Driver`)
 }
+
+func TestIndentedPlan(t *testing.T) {
+	tests := []struct {
+		T   *schema.Table
+		Cmd string
+	}{
+		{
+			T: schema.NewTable("t1").
+				AddColumns(schema.NewIntColumn("a", "int")),
+			Cmd: `CREATE TABLE "t1" (
+  "a" integer NOT NULL
+)`,
+		},
+		{
+			T: schema.NewTable("t1").
+				AddColumns(
+					schema.NewIntColumn("a", "int"),
+					schema.NewIntColumn("b", "int"),
+				),
+			Cmd: `CREATE TABLE "t1" (
+  "a" integer NOT NULL,
+  "b" integer NOT NULL
+)`,
+		},
+		{
+			T: schema.NewTable("t1").
+				AddColumns(
+					schema.NewIntColumn("a", "int"),
+					schema.NewIntColumn("b", "int"),
+				).
+				SetPrimaryKey(
+					schema.NewPrimaryKey(schema.NewIntColumn("id", "int")),
+				),
+			Cmd: `CREATE TABLE "t1" (
+  "a" integer NOT NULL,
+  "b" integer NOT NULL,
+  "id" integer NOT NULL,
+  PRIMARY KEY ("id")
+)`,
+		},
+		{
+			T: schema.NewTable("t1").
+				AddColumns(
+					schema.NewIntColumn("a", "int"),
+					schema.NewIntColumn("b", "int"),
+				).
+				AddForeignKeys(
+					schema.NewForeignKey("fk1").
+						AddColumns(schema.NewIntColumn("a", "int")).
+						SetRefTable(schema.NewTable("t2")).
+						AddRefColumns(schema.NewIntColumn("a", "int")),
+					schema.NewForeignKey("fk2").
+						AddColumns(schema.NewIntColumn("a", "int")).
+						SetRefTable(schema.NewTable("t2")).
+						AddRefColumns(schema.NewIntColumn("a", "int")),
+				),
+			Cmd: `CREATE TABLE "t1" (
+  "a" integer NOT NULL,
+  "b" integer NOT NULL,
+  CONSTRAINT "fk1" FOREIGN KEY ("a") REFERENCES "t2" ("a"),
+  CONSTRAINT "fk2" FOREIGN KEY ("a") REFERENCES "t2" ("a")
+)`,
+		},
+		{
+			T: schema.NewTable("t1").
+				AddColumns(
+					schema.NewIntColumn("a", "int"),
+					schema.NewIntColumn("b", "int"),
+				).
+				SetPrimaryKey(
+					schema.NewPrimaryKey(schema.NewIntColumn("id", "int")),
+				).
+				AddForeignKeys(
+					schema.NewForeignKey("fk1").
+						AddColumns(schema.NewIntColumn("a", "int")).
+						SetRefTable(schema.NewTable("t2")).
+						AddRefColumns(schema.NewIntColumn("a", "int")),
+					schema.NewForeignKey("fk2").
+						AddColumns(schema.NewIntColumn("a", "int")).
+						SetRefTable(schema.NewTable("t2")).
+						AddRefColumns(schema.NewIntColumn("a", "int")),
+				).
+				AddChecks(
+					schema.NewCheck().SetName("ck1").SetExpr("a > 0"),
+					schema.NewCheck().SetName("ck2").SetExpr("a > 0"),
+				),
+			Cmd: `CREATE TABLE "t1" (
+  "a" integer NOT NULL,
+  "b" integer NOT NULL,
+  "id" integer NOT NULL,
+  PRIMARY KEY ("id"),
+  CONSTRAINT "fk1" FOREIGN KEY ("a") REFERENCES "t2" ("a"),
+  CONSTRAINT "fk2" FOREIGN KEY ("a") REFERENCES "t2" ("a"),
+  CONSTRAINT "ck1" CHECK (a > 0),
+  CONSTRAINT "ck2" CHECK (a > 0)
+)`,
+		},
+	}
+	for i, tt := range tests {
+		t.Run(strconv.Itoa(i), func(t *testing.T) {
+			db, mk, err := sqlmock.New()
+			require.NoError(t, err)
+			mock{mk}.version("130000")
+			drv, err := Open(db)
+			require.NoError(t, err)
+			plan, err := drv.PlanChanges(context.Background(), "wantPlan", []schema.Change{&schema.AddTable{T: tt.T}}, func(opts *migrate.PlanOptions) {
+				opts.Indent = "  "
+			})
+			require.NoError(t, err)
+			require.Len(t, plan.Changes, 1)
+			require.Equal(t, tt.Cmd, plan.Changes[0].Cmd)
+		})
+	}
+}
