@@ -16,6 +16,7 @@ import (
 	"ariga.io/atlas/sql/sqlcheck/condrop"
 	"ariga.io/atlas/sql/sqlcheck/datadepend"
 	"ariga.io/atlas/sql/sqlcheck/destructive"
+	"ariga.io/atlas/sql/sqlcheck/incompatible"
 	"ariga.io/atlas/sql/sqlite"
 )
 
@@ -68,17 +69,25 @@ func init() {
 		if err != nil {
 			return nil, err
 		}
+		bc, err := incompatible.New(r)
+		if err != nil {
+			return nil, err
+		}
 		return []sqlcheck.Analyzer{
 			sqlcheck.AnalyzerFunc(func(ctx context.Context, p *sqlcheck.Pass) error {
 				var changes []*sqlcheck.Change
 				// Detect sequence of changes using temporary table and transform them to one ModifyTable change.
 				// See: https://www.sqlite.org/lang_altertable.html#making_other_kinds_of_table_schema_changes.
 				for i := 0; i < len(p.File.Changes); i++ {
-					if i+3 >= len(p.File.Changes) || !modifyUsingTemp(p.File.Changes[i], p.File.Changes[i+2], p.File.Changes[i+3]) {
+					if i+3 >= len(p.File.Changes) {
+						changes = append(changes, p.File.Changes[i])
+						continue
+					}
+					prevT, currT, ok := modifyUsingTemp(p.File.Changes[i], p.File.Changes[i+2], p.File.Changes[i+3])
+					if !ok {
 						changes = append(changes, p.File.Changes[i])
 						continue
 					}
-					prevT, currT := p.File.Changes[i+2].Changes[0].(*schema.DropTable).T, p.File.Changes[i+3].Changes[1].(*schema.AddTable).T
 					diff, err := p.Dev.Driver.TableDiff(prevT, currT)
 					if err != nil {
 						return nil
@@ -106,21 +115,35 @@ func init() {
 				p.File.Changes = changes
 				return nil
 			}),
-			ds, dd, cd,
+			ds, dd, cd, bc,
 		}, nil
 	})
 }
 
 // modifyUsingTemp indicates if the 3 changes represents a table modification using
 // the pattern mentioned in the link below: "CREATE", "INSERT", "DROP" and "RENAME".
-func modifyUsingTemp(c1, c2, c3 *sqlcheck.Change) bool {
-	if len(c1.Changes) != 1 || !isAddT(c1.Changes[0], "new_") || len(c2.Changes) != 1 || len(c3.Changes) != 2 {
-		return false
+func modifyUsingTemp(c1, c2, c3 *sqlcheck.Change) (from, to *schema.Table, _ bool) {
+	if len(c1.Changes) != 1 || !isAddT(c1.Changes[0], "new_") || len(c2.Changes) != 1 || len(c3.Changes) == 0 {
+		return nil, nil, false
 	}
+	// New table layout.
 	add := c1.Changes[0].(*schema.AddTable)
-	name := strings.TrimPrefix(add.T.Name, "new_")
-	// "DROP T" and "RENAME new_T to T".
-	return isDropT(c2.Changes[0], name) && isDropT(c3.Changes[0], add.T.Name) && isAddT(c3.Changes[1], name)
+	prefixed, name := add.T.Name, strings.TrimPrefix(add.T.Name, "new_")
+	add.T.Name = name
+	// Right after "INSERT", the "DROP T" is expected.
+	if !isDropT(c2.Changes[0], name) {
+		return nil, nil, false
+	}
+	drop := c2.Changes[0].(*schema.DropTable)
+	// "RENAME T" is expected after "DROP T".
+	if len(c3.Changes) == 1 && isRenameT(c3.Changes[0], prefixed, name) {
+		return drop.T, add.T, true
+	}
+	// In case no parser is attached, "RENAME T" will be presented as "DROP T" and "ADD T".
+	if len(c3.Changes) == 2 && isDropT(c3.Changes[0], prefixed) && isAddT(c3.Changes[1], name) {
+		return drop.T, add.T, true
+	}
+	return nil, nil, false
 }
 
 func isAddT(c schema.Change, prefix string) bool {
@@ -128,7 +151,12 @@ func isAddT(c schema.Change, prefix string) bool {
 	return ok && strings.HasPrefix(a.T.Name, prefix)
 }
 
-func isDropT(c schema.Change, prefix string) bool {
+func isDropT(c schema.Change, name string) bool {
 	d, ok := c.(*schema.DropTable)
-	return ok && strings.HasPrefix(d.T.Name, prefix)
+	return ok && d.T.Name == name
+}
+
+func isRenameT(c schema.Change, from, to string) bool {
+	r, ok := c.(*schema.RenameTable)
+	return ok && r.From.Name == from && r.To.Name == to
 }
